==> haskell-data-textual-0.3.0.2-5-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-data-textual.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: data-textual
version: 0.3.0.2
id: data-textual-0.3.0.2-Ar8TEyFYkmKHUdKg91QLc4
key: data-textual-0.3.0.2-Ar8TEyFYkmKHUdKg91QLc4
license: BSD3
copyright: 2013 Mikhail Vorozhtsov <mikhail.vorozhtsov@gmail.com>
maintainer: Mikhail Vorozhtsov <mikhail.vorozhtsov@gmail.com>
stability: experimental
homepage: https://github.com/mvv/data-textual
synopsis: Human-friendly textual representations.
description:
    This package provides an interface for converting between data and its
    (human-friendly) textual representation.
category: Data, Text
author: Mikhail Vorozhtsov <mikhail.vorozhtsov@gmail.com>
exposed: True
exposed-modules:
    Data.Textual Data.Textual.Integral Data.Textual.Fractional
abi: 5404ff36834f6706b576186de1ade3a6
trusted: False
import-dirs: /usr/lib/ghc-8.0.1/site-local/data-textual-0.3.0.2
library-dirs: /usr/lib/ghc-8.0.1/site-local/data-textual-0.3.0.2
data-dir: /usr/share/x86_64-linux-ghc-8.0.1/data-textual-0.3.0.2
hs-libraries: HSdata-textual-0.3.0.2-Ar8TEyFYkmKHUdKg91QLc4
depends:
    base-4.9.0.0 bytestring-0.10.8.1
    parsers-0.12.4-9TuAHJrDdtVLctSD9PovNx
    text-1.2.2.1-FgcR4Xf0VlEHD9HLxzq9WJ
    text-latin1-0.3-227Ci4RixWXG6lWZgYn13J
    text-printer-0.5-TanPJdZNqx8KqI4WUE9Tj
haddock-interfaces: /usr/share/doc/haskell-data-textual/html/data-textual.haddock
haddock-html: /usr/share/doc/haskell-data-textual/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-data-textual-0.3.0.2-6-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-data-textual.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: data-textual
version: 0.3.0.2
id: data-textual-0.3.0.2-IzPjZYoWF2QH8jd2hcmclj
key: data-textual-0.3.0.2-IzPjZYoWF2QH8jd2hcmclj
license: BSD3
copyright: 2013 Mikhail Vorozhtsov <mikhail.vorozhtsov@gmail.com>
maintainer: Mikhail Vorozhtsov <mikhail.vorozhtsov@gmail.com>
stability: experimental
homepage: https://github.com/mvv/data-textual
synopsis: Human-friendly textual representations.
description:
    This package provides an interface for converting between data and its
    (human-friendly) textual representation.
category: Data, Text
author: Mikhail Vorozhtsov <mikhail.vorozhtsov@gmail.com>
exposed: True
exposed-modules:
    Data.Textual Data.Textual.Integral Data.Textual.Fractional
abi: d70fb1981ad0020ca9c907552227f011
trusted: False
import-dirs: /usr/lib/ghc-8.0.1/site-local/data-textual-0.3.0.2
library-dirs: /usr/lib/ghc-8.0.1/site-local/data-textual-0.3.0.2
data-dir: /usr/share/x86_64-linux-ghc-8.0.1/data-textual-0.3.0.2
hs-libraries: HSdata-textual-0.3.0.2-IzPjZYoWF2QH8jd2hcmclj
depends:
    base-4.9.0.0 bytestring-0.10.8.1
    parsers-0.12.4-EBlSUG1fQQN7VVgX5vOcmk
    text-1.2.2.1-FgcR4Xf0VlEHD9HLxzq9WJ
    text-latin1-0.3-227Ci4RixWXG6lWZgYn13J
    text-printer-0.5-403cGoe6c08KytxWNU4hTL
haddock-interfaces: /usr/share/doc/haskell-data-textual/html/data-textual.haddock
haddock-html: /usr/share/doc/haskell-data-textual/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
